==> gobigger-0.1.0.tar.gz: gobigger-0.1.0/gobigger/managers/spore_manager.py <==
import math
import logging
import random
import uuid
from abc import ABC, abstractmethod
from easydict import EasyDict
from pygame.math import Vector2

from .base_manager import BaseManager
from gobigger.utils import format_vector, Border
from gobigger.balls import FoodBall, ThornsBall, CloneBall, SporeBall


class SporeManager(BaseManager):

    def __init__(self, cfg, border):
        super(SporeManager, self).__init__(cfg, border)

    def get_balls(self):
        return list(self.balls.values())
    
    def add_balls(self, balls):
        if isinstance(balls, list):
            for ball in balls:
                self.balls[ball.name] = ball
        elif isinstance(balls, SporeBall):
            self.balls[balls.name] = balls
        return True

    def remove_balls(self, balls):
        if isinstance(balls, list):
            for ball in balls:
                ball.remove()
                del self.balls[ball.name]
        elif isinstance(balls, SporeBall):
            balls.remove()
            del self.balls[balls.name]

    def spawn_ball(self, position=None, size=None):
        if position is None:
            position = self.border.sample()
        if size is None:
            size = random.uniform(self.ball_settings.radius_min, self.ball_settings.radius_max)**2
        name = uuid.uuid1()
        return SporeBall(name=name, position=position, border=self.border, direction=Vector2(1,0), vel_init=0)
    
    def init_balls(self, custom_init=None):
        if custom_init is not None:
            for ball_cfg in custom_init:
                ball = self.spawn_ball(position=Vector2(*ball_cfg['position']), size=ball_cfg['radius']**2)
                self.balls[ball.name] = ball

    def step(self, duration):
        return

    def reset(self):
        self.balls = {}
        return True

==> gobigger-0.1.3.tar.gz: gobigger-0.1.3/gobigger/managers/spore_manager.py <==
import math
import logging
import random
import uuid
from abc import ABC, abstractmethod
from easydict import EasyDict
from pygame.math import Vector2

from .base_manager import BaseManager
from gobigger.utils import format_vector, Border
from gobigger.balls import FoodBall, ThornsBall, CloneBall, SporeBall


class SporeManager(BaseManager):

    def __init__(self, cfg, border):
        super(SporeManager, self).__init__(cfg, border)

    def get_balls(self):
        return list(self.balls.values())
    
    def add_balls(self, balls):
        if isinstance(balls, list):
            for ball in balls:
                self.balls[ball.name] = ball
        elif isinstance(balls, SporeBall):
            self.balls[balls.name] = balls
        return True

    def remove_balls(self, balls):
        if isinstance(balls, list):
            for ball in balls:
                ball.remove()
                del self.balls[ball.name]
        elif isinstance(balls, SporeBall):
            balls.remove()
            del self.balls[balls.name]

    def spawn_ball(self, position=None, size=None):
        if position is None:
            position = self.border.sample()
        if size is None:
            size = random.uniform(self.ball_settings.radius_min, self.ball_settings.radius_max)**2
        name = uuid.uuid1()
        return SporeBall(name=name, position=position, border=self.border, direction=Vector2(1,0), vel_init=0)
    
    def init_balls(self, custom_init=None):
        # [position.x, position.y, radius, direction.x, direction.y, vel.x, vel.y, acc.x, acc.y, 
        #  move_time, moving]
        if custom_init is not None:
            for ball_cfg in custom_init:
                ball = self.spawn_ball(position=Vector2(*ball_cfg[:2]), size=ball_cfg[2]**2)
                ball.direction = Vector2(*ball_cfg[3:5])
                ball.vel = Vector2(*ball_cfg[5:7])
                ball.acc = Vector2(*ball_cfg[7:9])
                ball.move_time = ball_cfg[9]
                ball.moving = ball_cfg[10]
                self.balls[ball.name] = ball

    def step(self, duration):
        return

    def reset(self):
        self.balls = {}
        return True
